@@ -6,13 +6,14 @@ from datetime import datetime, timedelta
 from pytz import timezone
 from primestg.ziv_service import ZivService
 import base64
+from primestg.cycle.cycles import CycleFile
 
 TZ = timezone('Europe/Madrid')
 
 from primestg.service import Service, format_timestamp
 from primestg.contract_templates import CONTRACT_TEMPLATES
 from primestg.utils import DLMSTemplates
-
+import json
 
 REPORTS = [
     'get_instant_data',
@@ -28,9 +29,12 @@ ORDERS = {
     'connect': {'order': 'B03', 'func': 'get_cutoff_reconnection'},
     # CONTRACT
     'contract': {'order': 'B04', 'func': 'get_contract'},
+    'powers': {'order': 'B02', 'func': 'get_powers'},
     'dlms': {'order': 'B12', 'func': 'order_raw_dlms'},
     # CNC config
-    'cnc_ftpip': {'order': 'B07', 'func': 'set_concentrator_ipftp'}
+    'cnc_ftpip': {'order': 'B07', 'func': 'set_concentrator_ip'},
+    'cnc_ftpntp': {'order': 'B07', 'func': 'set_concentrator_ip'},
+    'cnc_ftpstg': {'order': 'B07', 'func': 'set_concentrator_ip'},
 }
 
 
@@ -112,7 +116,7 @@ def get_sync_sxx(**kwargs):
 )
 @click.option("--ip", "-i", default="10.26.0.4", help='IP i.e CNC FTPIp')
 def sends_order(**kwargs):
-   """Sends on of available Orders to Meter or CNC"""
+   """Sends one of available Orders to Meter or CNC"""
    id_pet = get_id_pet()
    s = Service(id_pet, kwargs['cnc_url'], sync=True)
    order_name = kwargs['order']
@@ -147,6 +151,13 @@ def sends_order(**kwargs):
                datetime.strptime(kwargs['activation_date'], '%Y-%m-%d %H:%M:%S')
            )
        }
+   elif order_name == 'powers':
+       vals = {
+           'powers': kwargs['powers'].split(','),
+           'activation_date': TZ.localize(
+               datetime.strptime(kwargs['activation_date'], '%Y-%m-%d %H:%M:%S')
+           )
+       }
    elif order_name == 'dlms':
        try:
            # datetime
@@ -237,5 +248,12 @@ def send_ziv_cycle(**kwargs):
     result = zs.send_cycle(filename=kwargs['filename'], cycle_filedata=content)
     print(result.content)
 
+@primestg.command(name='parse_cycle')
+@click.argument('filename', required=True)
+def parse_cycle(**kwargs):
+    """Prints dict with cycle data from CNC csv"""
+    c = CycleFile(path=kwargs['filename'])
+    print(json.dumps(c.data, indent=4, default=str))
+
 if __name__ == 'main':
     primestg()
