@@ -78,6 +78,15 @@ class Service(object):
         results = self.DC_service.Order(self.fact_id, 0, order, priority)
         return results
 
+    def get_powers(self, generic_values, payload):
+        """
+        Sends B02 order to meter
+        :return: Success or fail
+        """
+        order = Order('B02')
+        order = order.create(generic_values, payload)
+        return self.send_order('B02', order)
+
     def get_cutoff_reconnection(self, generic_values, payload):
         """
         Sends B03 order to meter
@@ -105,8 +114,8 @@ class Service(object):
         order = order.create(generic_values, payload)
         return self.send_order('B07', order)
 
-    def set_concentrator_ipftp(self, generic_values, payload):
-        order = Order('B07_ipftp')
+    def set_concentrator_ip(self, generic_values, payload):
+        order = Order('B07_ip')
         order = order.create(generic_values, payload)
         return self.send_order('B07', order)
 
@@ -257,6 +266,21 @@ class Service(object):
         """
         return self.send('S12', dc, date_from, date_to)
 
+    def get_daily_average_voltage_and_current(self, meters, date_from, date_to):
+        """
+        Asks for a S14 report to the specified meter.
+        :param meters: a meter_id
+        :return: an S14 report for the corresponding meter
+        """
+        return self.send('S14', meters, date_from, date_to)
+
+    def get_all_daily_average_voltage_and_current(self, date_from, date_to):
+        """
+        Asks for a S14 report to all meters.
+        :return: an S14 report from every meter
+        """
+        return self.send('S14', '', date_from, date_to)
+
     def get_concentrator_events(self, dc, date_from, date_to):
         """
         Asks for a S17 report to the concentrator.
@@ -264,6 +288,21 @@ class Service(object):
         """
         return self.send('S17', dc, date_from, date_to)
 
+    def get_cutoffs_status(self, meters, date_from, date_to):
+        """
+        Asks for a S18 report to the specified meter.
+        :param meters: a meter_id
+        :return: an S18 report for the corresponding meter
+        """
+        return self.send('S18', meters, date_from, date_to)
+
+    def get_all_cutoffs_status(self, date_from, date_to):
+        """
+        Asks for a S18 report to all meters.
+        :return: an S18 report from every meter
+        """
+        return self.send('S18', '', date_from, date_to)
+
     def get_all_contract_definition(self, date_from, date_to):
         """
         Asks for a S23 report to all meters.
@@ -277,3 +316,10 @@ class Service(object):
         :return: an S24 report from the concentrator.
         """
         return self.send('S24', dc, date_from, date_to)
+
+    def get_current_billing(self, meter, date_from, date_to):
+        """
+        Asks for a S27 report to the meter.
+        :return: an S27 report from the meter.
+        """
+        return self.send('S27', meter, date_from, date_to)
\ No newline at end of file
